#
# spec file for package kwindowsystem
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5WindowSystem5
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%define qt5_version 5.15.2
%bcond_without released
Name:           kwindowsystem
Version:        5.116.0
Release:        1.6
Summary:        KDE Access to window manager
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{name}-%{version}.tar.xz
%if %{with released}
Source1:        %{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  extra-cmake-modules >= %{_kf5_version}
BuildRequires:  fdupes
BuildRequires:  pkgconfig
BuildRequires:  cmake(Qt5LinguistTools) >= %{qt5_version}
BuildRequires:  cmake(Qt5Test) >= %{qt5_version}
BuildRequires:  cmake(Qt5Widgets) >= %{qt5_version}
BuildRequires:  cmake(Qt5X11Extras) >= %{qt5_version}
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-keysyms)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xrender)

%description
Convenience access to certain properties and features of the window manager.

KWindowSystem provides information about the state of the window manager and
allows asking the window manager to change the using a more high-level
interface than the NETWinInfo/NETRootInfo low-level classes.

%package -n %{lname}
Summary:        KDE Access to window manager
%requires_ge    libQt5Widgets5
%requires_ge    libQt5X11Extras5

%description -n %{lname}
Convenience access to certain properties and features of the window manager.

KWindowSystem provides information about the state of the window manager and
allows asking the window manager to change the using a more high-level
interface than the NETWinInfo/NETRootInfo low-level classes.

%package devel
Summary:        KDE Access to window manager: Build Environment
Requires:       %{lname} = %{version}
Requires:       cmake(Qt5Core) >= %{qt5_version}
Requires:       cmake(Qt5Widgets) >= %{qt5_version}
Requires:       pkgconfig(x11)
Requires:       pkgconfig(xcb)

%description devel
Convenience access to certain properties and features of the window manager.

KWindowSystem provides information about the state of the window manager and
allows asking the window manager to change the using a more high-level
interface than the NETWinInfo/NETRootInfo low-level classes.
Development files.

%lang_package -n %{lname}

%prep
%autosetup -p1

%build
%cmake_kf5 -d build -- -Dlconvert_executable=%{_kf5_libdir}/qt5/bin/lconvert
%cmake_build

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang kwindowsystem5 --with-qt --without-mo

%ldconfig_scriptlets -n %{lname}

%files -n %{lname}-lang -f kwindowsystem5.lang

%files -n %{lname}
%license LICENSES/*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kwindowsystem
%{_kf5_debugdir}/kwindowsystem.categories
%{_kf5_debugdir}/*.renamecategories
%{_kf5_libdir}/libKF5WindowSystem.so.*
%{_kf5_plugindir}/kf5/kwindowsystem/KF5WindowSystemX11Plugin.so

%files devel
%{_kf5_includedir}/
%{_kf5_libdir}/cmake/KF5WindowSystem/
%{_kf5_libdir}/libKF5WindowSystem.so
%{_kf5_mkspecsdir}/qt_KWindowSystem.pri

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.116.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.116.0
- No code change since 5.115.0
* Thu Feb  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.115.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.115.0
- No code change since 5.114.0
* Sat Jan 13 2024 Christophe Marin <christophe@krop.fr>
- Update to 5.114.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.114.0
- No code change since 5.113.0
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.113.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.113.0
- No code change since 5.112.0
* Mon Nov  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.112.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.112.0
- No code change since 5.111.0
* Mon Oct  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.111.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.111.0
- Changes since 5.110.0:
  * Explain in deprecation message that logical coordinates must be used in KF6
* Wed Sep  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.110.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.110.0
- No code change since 5.109.0
* Tue Aug  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.109.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.109.0
- Changes since 5.108.0:
  * Add explicit moc includes to sources for moc-covered headers
* Mon Jul  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.108.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.108.0
- Changes since 5.107.0:
  * Remove qt6 CI builds
* Mon Jun  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.107.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.107.0
- No code change since 5.106.0
* Sat May  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.106.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.106.0
- No code change since 5.105.0
* Sat Apr  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.105.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.105.0
- No code change since 5.104.0
* Mon Mar  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.104.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.104.0
- Changes since 5.103.0:
  * Remove extra semicolon
  * Deprecated KWindowSystem::allowExternalProcessWindowActivation
  * [kstartupinfo] Deprecate setWindowStartupId
  * [kstartupinfo] Deprecate KStartupInfo::currentStartupIdEnv
  * [kstartupinfo] Fix API docs for currentStartupIdEnv
* Wed Feb  8 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.103.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.103.0
- No code change since 5.102.0
* Thu Jan 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.102.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.102.0
- Changes since 5.101.0:
  * Merge two KWINDOWSYSTEM_HAVE_X11 sections into one
  * Fix KStartupInfo::appStarted()
  * Deprecate KStartupInfo::startupId()
  * Deprecate KStartupInfo::silenceStartup
  * Add a formatting commit to blame ignore list
  * KWindowSystemPluginWrapper doesn't need a virtual dtor
  * Make KX11Extras::icon behave like KWindowSytem::icon (kde#462739)
* Tue Dec  6 2022 Christophe Marin <christophe@krop.fr>
- Update to 5.101.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.101.0
- Changes since 5.100.0:
  * Use QGuiApplication to read devicePixelRatio
  * Deprecate KWindowSystem::demandAttention
  * Deprecate KWindowSystem::setIcons
  * Move X11-specific KWindowSystem functions to new KX11Extras class
  * xcb/kwindoweffects: Fix stripes when dpr is not an integer.
  * Deprecate KWindowSystem::setUserTime
  * Deprecate KWindowSystem::setBlockingCompositing
  * Deprecate KWindowSystem::icccmCompliantMappingState
  * Deprecate KWindowSystem::lowerWindow
  * Deprecate KWindowSystem::constrainViewportRelativePosition
  * Port to PMF signal/slot syntax
* Tue Nov  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.100.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.100.0
- Changes since 5.99.0:
  * Fix the translation folder name
* Sat Oct  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.99.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.99.0
- Changes since 5.98.0:
  * Add Qt6 windows CI support
  * Port QtWinExtra uses for Qt 6
  * Remove QWindow::isExposed() check in activateWindow() (kde#458983)
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.98.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.98.0
- Changes since 5.97.0:
  * Remove extra ';'
  * Add FreeBSD Qt6 CI support
* Sun Aug  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.97.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.97.0
- Changes since 5.96.0:
  * Doc: Update WM spec URL
* Sun Jul  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.96.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.96.0
- Changes since 5.95.0:
  * Make enum Q_ENUM
  * Implement _GTK_SHOW_WINDOW_MENU.
* Fri Jun 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.95.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.95.0
- Changes since 5.94.0:
  * port to standard C++ smart pointers where possible
  * Add a new window type named AppletPopup.
  * Fix API docs for requestXdgActivationToken
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.94.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.94.0
- Changes since 5.93.0:
  * autotests: improve test-reporting, comment-typo
  * Require passing tests
  * Fix skipping wayland test when weston is not found
  * Mark as supported on Android
  * Add windows CI
* Sun Apr  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.93.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.93.0
- No code change since 5.92.0
* Mon Mar  7 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.92.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.92.0
- Changes since 5.91.0:
  * Add Qt6 Android CI
  * Ensure that xdgActivationTokenArrived is always emitted asynchronously (kde#450342)
* Sun Feb  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.91.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.91.0
- Changes since 5.90.0:
  * Check executables exist in PATH before passing them to QProcess
  * fix typo
  * install plugins in kf<version>
  * Fix doxygen docs for requestXdgActivationToken
  * Add CI qt6 support
  * Avoid XKeycodeToKeysym in KKeyServer::initializeMods (kde#426684)
  * Remove placeholder wayland platform plugin
  * [kwindowinfo] Add support for reading _GTK_APPLICATION_ID
  * Add KWindowSystem::updateStartupId(QWindow *window)
* Mon Jan  3 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.90.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.90.0
- Changes since 5.89.0:
  * Fix kkeyserver_x11_unittest by using static QChar::isLetter()
  * Change the build system to enable building with Qt 6
  * Avoid using QByteArray::operator[] for the null terminator (kde#434557)
  * doc: Add missing @since in KWindowSystem
  * Avoid creating and leaking QWindows
* Sat Dec  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.89.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.89.0
- Changes since 5.88.0:
  * Make KWindowSystem a bit easier to integrate in QML
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Strip 'Source' URL for faster submissions
* Sun Nov  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.88.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.88.0
- Changes since 5.87.0:
  * Fix the compiler warning by casting int to unsigned.
  * Link privately against XCB when building statically (kde#441266)
  * Add FreeBSD CI
  * Add Android CI
  * Enable CI deps on all platfoprms
  * Update .kde-ci.yml: add FreeBSD
* Sun Oct  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.87.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.87.0
- Changes since 5.86.0:
  * Add Gitlab CI configuration
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the unneeded baselibs.conf.
* Mon Sep  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.86.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.86.0
- Too many changes since 5.85.0, only listing bugfixes:
  * Read uncomplete WM_CLASS string (kde#441005)
  * Don't link publicly against XCB (kde#441266)
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.85.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.85.0
- Changes since 5.84.0:
  * Support static builds
* Sun Jul  4 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.84.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.84.0
- Changes since 5.83.0:
  * Remove unused includes
- Only install the license files once
* Sat Jun  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.83.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.83.0
- Changes since 5.82.0:
  * Provide KWindowSystem::lastInputSerial
  * Include API for wayland's xdg_activation_V1
  * Bump required CMake version to 3.16
  * Drop Qt5Widgets dependency if KWINDOWSYSTEM_NO_WIDGETS=ON
* Sat May  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.82.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.82.0
- Changes since 5.81.0:
  * Deprecate present windows and highlight windows apis
  * Properly guard deprecated code in autotests
  * Deprecate WId-based effects API
  * Use new version-controlled enumerator deprecation warning macros
  * Add clang-format pre-commit hook
  * Run clang-format
  * Prevent clang-format uglification
  * Add trailing comma to enum
  * Deprecate KWindowEffects::windowSizes
* Mon Apr  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.81.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.81.0
- Changes since 5.80.0:
  * Add MediaPause key to mapping (kde#403636)
* Sun Mar  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.80.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/frameworks/5/5.80.0
- Changes since 5.79.0:
  * Un-overload windowChanged() signal
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.79.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.79.0
- Changes since 5.78.0:
  * Add fractional opacity convenience helpers
  * Really fix includes
  * Fix includes
  * xcb: Work with the active screen as reported by QX11Info::appScreen().
* Wed Jan  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.78.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.78.0
- Changes since 5.77.0:
  * Not necessary to use QtTest as it includes all QtCore include
* Mon Dec  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.77.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.77.0
- Changes since 5.76.0:
  * Pass parent to Q*Layout ctor instead of calling setLayout()
  * Load statically linked integration plugins
  * Portaway from pid() to processId()
* Sat Nov  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.76.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.76.0
- Changes since 5.75.0:
  * If include is define in .h remove it if it's defined in .cpp too (scripted)
  * xcb: Fix detection of screen sizes for High-DPI
* Mon Oct  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.75.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.75.0
- Changes since 5.74.0:
  * Remove obsolete license texts
  * Relicense the file to LGPL-2.1-or-later
  * Relicense files to be compatible with LGPL-2.1
* Sun Sep  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.74.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.74.0
- Changes since 5.73.0:
  * Install platform plugins in a directory with no dots in file name (kde#425652)
  * [xcb] Scaled icon geometry correctly everywhere
  * Remove obsolete COPYING files
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.73.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.73.0
- Changes since 5.72.0:
  * Use KF-standardized Qt logging categories
  * Use camelcase include. (scripted)
* Sun Jul  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.72.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.72.0
- Changes since 5.71.0:
  * [xcb] Send correctly scaled icon geometry (kde#407458)
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Fix doc: Use pid() when documenting the pid() method
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * Print meaningful warning when there is no QGuiApplication
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * Fix EWMH non-compliance for NET::{OnScreenDisplay,CriticalNotification}
  * KWindowSystem: deprecate KStartupInfoData::launchedBy, unused
  * Expose application menu via KWindowInfo
  * KWindowSystem: Convert license headers to SPDX expressions
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * Make it compile against qt5.15. SkipEmptyParts is part of Qt::.
  * Use ecm_qt_install_logging_categories over manual categories file
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * [KWindowShadows] Check for X connection
  * Fix build on FreeBSD
  * Introduce shadows API
  * Deprecate KWindowEffects::markAsDashboard()
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * In qt5.15 endl is namespaced. But qCCritical already adds "\n"
    at the end, so we can remove it.
  * qrand is deprecated in qt5.15.
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * Adjust count after _GTK_FRAME_EXTENTS addition
  * Add support for _GTK_FRAME_EXTENTS
  * use modern for syntax
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Set QT_DISABLE_DEPRECATED_BEFORE and others
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Changes since 5.62.0:
  * Set XCB to required if building the X backend
  * Port away from Qt's foreach
  * Add missing QHash include to fix compilation with Qt 5.14
  * Make less use of deprecated enum alias NET::StaysOnTop
  * KStartupInfo: drop dead code for removing quotes from data values
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * KWindowSystem: add cmake option KWINDOWSYSTEM_NO_WIDGETS
  * Deprecate slideWindow(QWidget *widget)
  * KWindowSystem: fix compilation with KWINDOWSYSTEM_NO_DEPRECATED
  * Add KWindowSystem::setMainWindow(QWindow *) overload
  * KWindowSystem: add setNewStartupId(QWindow *...) overload
  * KWindowSystem: remove unused QWidget includes
  * KWindowSystem: port from QApplication to QCoreApplication
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * [platforms/xcb] Use XRES extension to get real window PID (kde#384837)
  * Fix failing autotest
  * Port KXMessages away from QWidget
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * Install in new logging directory when we use kf5 5.59.0
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- No code changes since 5.58.0
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * API dox: fix typo
  * Introduce CriticalNotificationType
  * Adjust unit test for newly added state
  * Support NET_WM_STATE_FOCUSED
  * Document that modToStringUser and stringUserToMod only deal with english strings
  * Replace count() == 0 by isEmpty()
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Use debug categories here
  * port to std::sort
  * Send blur/background contrast in device pixels (kde#404923)
  * [autotests] Fix KWindowInfoX11Test::testState
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * No code changes since 5.55.0
* Fri Feb 15 2019 alarrosa@suse.com
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * autotests: fix it, since nobody else did, grmbl
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * No code changes since 5.53.0
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * autotests: cast to int so that the values appear.
  * Use isEmpty()
  * Remove qt include prefix
  * normalize signal/slot
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * don't assign variable to itself
  * Add categories file here
  * Use qEnvironmentVariableIsEmpty
  * Remove unused variable
  * Do not compare iterators returned from two separate returned copies
  * Call reserve() on Qt containers if fill size is known before
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Use _NET_WM_WINDOW_TYPE_COMBO instead of _NET_WM_WINDOW_TYPE_COMBOBOX
  * API dox: 0 -> nullptr
  * Use QString's multi-arg with multiple string args
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * None
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Use consistently nullptr
  * Use consistently override
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * None
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * None
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Add "SkipSwitcher" to API
  * Autogenerate debug file
  * We depend against 5.8.0
  * Fix narrowing conversion warning on gcc and error on clang/FreeBSD
  * [xcb] Fix implementation of _NET_WM_FULLSCREEN_MONITORS (kde#391960)
  * Reduce plasmashell frozen time
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.0:
  * autotests: set LIBRARY_OUTPUT_DIRECTORY so platform plugins are found uninstalled
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.0.php
- Changes since 5.41.0:
  * Remove obsolete reviewboardrc file
  * Verify return value
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * [KWindowEffectsPrivateX11] Add reserve() call
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * KKeyServer: fix handling of Meta+Shift+Print, Alt+Shift+arrowkey etc.
  * Support flatpak platform
  * Use KWindowSystem's own platform detection API instead of duplicated code
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * Find test helper
  * Find test helper
  * Fix build with Qt 5.10
  * autotest: test the shortcuts broken by last month's changes.
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
  * Restore behaviour of KKeyServer::symXToKeyQt
  * KKeyServer: fix handling of KeypadModifier.
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * Remove header reliance on QWidget
  * Use more nullptr
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * cmake: use ecm_add_test more
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * Better fix for NetRootInfoTestWM in path with spaces
  * Revert broken fix TestKWindowsystemPlatformWayland in path with spaces
  * Un-bitrot debug code
  * Fix TestKWindowsystemPlatformWayland & NetRootInfoTestWM in path with spaces
  * use Q_FALLTHROUGH
  * Use explicit flag values or explicit constructor instead of nullptr
  * Add .arcconfig
  * API dox: Fix usage of @link, using JavaDoc style
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * None
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Upgrade KF5 version to 5.32.0.
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * [KWindowInfo] Add pid() and desktopFileName()
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Improved relocatability of CMake export
  * Add support for desktopFileName to NETWinInfo
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * [xcb] Ensure the compositingChanged signal is emitted if
    NETEventFilter is recreated (kde#362531)
  * Add a convenience API to query the windowing system/platform used by Qt
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
- Drop upstreamed compositingchanged.patch
* Wed Aug  3 2016 fabian@ritter-vogt.de
- Add compositingchanged.patch from https://git.reviewboard.kde.org/r/128576/
    to fix kde#362531
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * [platform xcb] Respect request icon size (kde#362324)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * Fix generation of path to xcb plugin
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * Support _NET_WM_BYPASS_COMPOSITOR (kde#349910)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Change licence header from "Library GPL 2 or later" to "Lesser GPL 2.1 or later"
  * Fix crash if KWindowSystem::mapViewport is called without a QCoreApplication
  * Cache QX11Info::appRootWindow in eventFilter (kde#356479)
  * Get rid of QApplication dependency (kde#354811)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * Add xcb variant for static KStartupInfo::sendFoo methods
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Perform deep copy of QByteArray get_stringlist_reply
  * Allow interacting with multiple X servers in the NETWM classes.
  * [xcb] Consider mods in KKeyServer as initialized on platform != x11
  * Change KKeyserver (x11) to categorized logging
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * Harden NETWM data reading (kde#350173)
  * Guard for older Qt versions like in kio-http
  * Private headers for platform plugins are installed.
  * Platform specific parts loaded as plugins.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
- Drop 0001-Harden-NETWM-data-reading.patch, merged upstream
* Thu Jul 30 2015 hrvoje.senjan@gmail.com
- Added 0001-Harden-NETWM-data-reading.patch (kde#350173)
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * Don't depend on QX11Info in KXUtils::createPixmapFromHandle
    (kde#346496)
  * New method NETWinInfo::xcbConnection() -> xcb_connection_t*
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Add a dummy Wayland implementation for KWindowSystemPrivate
  * KWindowSystem::icon with NETWinInfo not bound to platform X11.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * KSelectionWatcher and KSelectionOwner can be used without
    depending on QX11Info.
  * KXMessages can be used without depending on QX11Info
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Fixed NETRootInfo::setShowingDesktop(bool) not
    working on Openbox
  * Added convenience method KWindowSystem::setShowingDesktop(bool)
  * Fixes in icon format handling
  * Added method NETWinInfo::icccmIconPixmap provides icon pixmap
    from WM_HINTS property
  * Added overload to KWindowSystem::icon which reduces
    roundtrips to X-Server
  * Added support for _NET_WM_OPAQUE_REGION
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Add OnScreenDisplay window type
  * Fix build on FreeBSD
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
- Make sure that devel package requires pkgconfig(x11) and
  pkgconfig(xcb), they are now public dependencies
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Add KStartupInfo::createNewStartupIdForTimestamp
  * Add support for more multimedia keys
  * Add support for initial mapping state of WM_HINTS
  * Drop incorrect warnings when using KXMessages without QX11Info
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
- Drop 0001-Fix-incorrect-count-of-netwm-atoms.patch, merged upstream
* Fri Oct 10 2014 hrvoje.senjan@gmail.com
- Added 0001-Fix-incorrect-count-of-netwm-atoms.patch, kde#339771
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * NETWinInfo now provides convenient wrapper for WM_PROTOCOLS.
  * NETWinInfo now provides convenient wrapper for input and urgency
    hints of WM_HINTS property.
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
- Drop patches merged upstream:
  0001-Make-constants-const-saves-a-few-symbols-in-the-.dat.patch,
  0002-Add-support-for-urgency-hint-in-NETWinInfo.patch,
  0003-Add-support-for-input-hint-in-NETWinInfo.patch and
  0007-Add-support-for-protocols-to-NETWinInfo.patch
* Wed Sep 24 2014 hrvoje.senjan@gmail.com
- Added patches needed for KWin's 5.1 release, all from upstream:
  0001-Make-constants-const-saves-a-few-symbols-in-the-.dat.patch,
  0002-Add-support-for-urgency-hint-in-NETWinInfo.patch,
  0003-Add-support-for-input-hint-in-NETWinInfo.patch and
  0007-Add-support-for-protocols-to-NETWinInfo.patch
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KWindowSystem: New method KWindowSystem::setOnActivities
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Harden required Qt5 libs versions
- Pass the location of lconvert executable
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kwindowsystem package
